@@ -2,7 +2,7 @@ from ..base import BaseModel
 
 
 class PhotoSizes(BaseModel):
-    src: str = None
+    url: str = None
     width: int = None
     height: int = None
     type: str = None
