@@ -1,6 +1,6 @@
 from ..base import BaseModel
 
-from vk_types import Photo
+from vk_types.attachments import Photo
 
 
 class Album(BaseModel):
